import { AssetManager } from "./asset-manager.js";
export class ModuleAssetDynamic {
    constructor(assetKey, loadModule) {
        this.isStaticImport = false;
        this.assetKey = assetKey;
        this.loadModule = loadModule;
    }
    getModule() {
        if (this._modulePromise === undefined) {
            this._modulePromise = this.loadModule();
        }
        return this._modulePromise;
    }
    getStaticModule() {
        return null;
    }
}
export class ModuleAssetStatic {
    constructor(assetKey, module) {
        this.isStaticImport = true;
        this.assetKey = assetKey;
        this.module = module;
    }
    getModule() {
        return Promise.resolve(this.module);
    }
    getStaticModule() {
        return this.module;
    }
}
export class ModuleAssets extends AssetManager {
    constructor(moduleAssetMap) {
        super();
        for (const [assetKey, moduleEntry] of Object.entries(moduleAssetMap)) {
            let asset;
            if (moduleEntry.isStaticImport) {
                asset = new ModuleAssetStatic(assetKey, moduleEntry.module);
            }
            else {
                asset = new ModuleAssetDynamic(assetKey, moduleEntry.loadModule);
            }
            this.setAsset(assetKey, asset);
        }
    }
}
