export function buildNormalizeFunctionForObject(action) {
    return (obj, errCtx = []) => {
        if (obj == null) {
            errCtx.push('obj cannot be null.');
            return null;
        }
        const errors = [];
        const normalizedObj = action(obj, errors);
        for (const error of errors) {
            errCtx.push(error);
        }
        return normalizedObj;
    };
}
export function buildNormalizeFunctionForArray(action) {
    return (obj, errCtx = []) => {
        if (!Array.isArray(obj)) {
            errCtx.push('obj must be array.');
            return null;
        }
        const errors = [];
        let normalizedEntries = [];
        for (const [index, entry] of obj.entries()) {
            const innerErrors = [];
            const normalizedEntry = action(entry, innerErrors);
            if (normalizedEntry != null) {
                normalizedEntries.push(normalizedEntry);
            }
            else {
                errors.push(`Item [${index + 1}]:`);
                errors.push(...innerErrors);
            }
        }
        if (errors.length > 0) {
            normalizedEntries = null;
        }
        for (const error of errors) {
            errCtx.push(error);
        }
        return normalizedEntries;
    };
}
export function isStringAndNotEmpty(str) {
    return typeof str === 'string' && str !== '';
}
export function isSpecified(obj, key) {
    return key in obj;
}
export function applyDefaults(data, defaults) {
    // Remove undefined values
    const temp = Object.assign({}, data);
    for (const [key, value] of Object.entries(temp)) {
        if (value === undefined) {
            delete temp[key];
        }
    }
    return Object.assign({}, defaults, temp);
}
